# Thonny black code format plugin
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI version](https://img.shields.io/pypi/v/thonny-black-format.svg)](https://pypi.org/project/thonny-black-format/)
[![PyPI py versions](https://img.shields.io/pypi/pyversions/thonny-black-format.svg)](https://pypi.org/project/thonny-black-format/)
[![PYPI license](https://img.shields.io/pypi/l/thonny-black-format.svg)](https://pypi.org/project/thonny-black-format/)
## Automatically format your python code with Black!

### Installation

1. This can be easily installed via Thonny. Go to `Tools -> Manage plug-ins...`, type `thonny-black-format` and click on `Find package from PyPI`. Install the plugin and restart Thonny.
1. Alternatively, you can install via pip with `pip install --user thonny-black-format`

### Usage
There are two ways to run the plugin:
1. Go to `Tools -> Format with Black`
1. Press `Ctrl+Alt+c`

All changes will be automatically saved. If you prefer, you can undo them.

### Contributing
Contributions are welcome! Feel free to sumbit an issue and/or a pull request.

### Useful links:

[PyPI](https://pypi.org/project/thonny-black-format/)

[Thonny](https://thonny.org/)

[Black](https://black.readthedocs.io/en/stable/)
